# @e9ine/eslint-config-vue

This package provides e9ine's .eslintrc as an extensible shared config for vue projects

## Usage

We export 1 ESLint configurations for your usage which already inherits eslint-recommended config. So you do not need to extend ```eslint:recommended```

Our default export contains all of our ESLint rules, including ECMAScript 6+ . It has its peer dependencies eslint so you **do not require** to install ```eslint``` separately

### Installation

1. Install the correct and latest version of the package

    ```$xslt
    npm install --save-dev @e9ine/eslint-config-vue
    ```

2. Make sure to extend the configurations to package.json

    ```$xslt
    ...
    
    "devDependencies": {
        ...
        "@e9ine/eslint-config-vue": "^1.0.0"
    },
    "eslintConfig": {
        "root": true,
        "extends": [
          "@e9ine/eslint-config-vue"
        ]
    }
    ```

3. Add below two scripts for lint and lint-fix

    ```$xslt
    ...
    
    "scripts": {
        ...
        "lint-fix": "eslint --ignore-path .gitignore . --fix"
    },
    
    ...
    ```

### Integration with husky

```husky``` can be integrated with the projects based on the team size. However we highly recommend to use husky 

1. Install husky as dev dependency

    ```$xslt
    npm install --save-dev husky
    ```

2. Define husky config in package.json

    ```$xslt
    ...
   
    "husky": {
        "hooks": {
          "pre-commit": "npm run lint"
        }
     }
    ```

### Integration with lint-staged

```lint-staged``` can be highly effective when you only would want to run linters on staged-files. This will also prevent the user from committing code which is not in compliance with the standards and specified formatting.

However we highly recommend to use lint-staged in combination with husky if you are working in a team consisting more than 2 members.

1. Install lint-staged as dev dependency

    ```$xslt
    npm install --save-dev lint-staged
    ```

2. Define lint-staged config in package.json

    ```$xslt
    "husky": {
        "hooks": {
          "pre-commit": "lint-staged"
        }
    },
      "lint-staged": {
        "*.js": ["./node_modules/.bin/eslint --fix", "git add"]
    }
    ```
   
--fix option will try to fix the formatting and fixable errors. If there are still any "manual-only-fixable" error found, then commit will be rejected.
